/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.tubemq.manager.service;

public class TubeMQErrorConst {
    public static final String PARAM_ILLEGAL = "param illegal";
    public static final String BROKER_IN_OTHER_REGION = "resource already used";
    public static final String RESOURCE_NOT_EXIST = "resource not exist";
    public static final String MYSQL_ERROR = "mysql error";
    public static final String NO_SUCH_CLUSTER = "no such cluster";
    public static final String NO_SUCH_METHOD = "no such method";
    public static final String NO_SUCH_GROUP = "no such group";
}
